@@ -1,20 +1,21 @@
 #' Generate the bibliography
-#' @param style formatting style to print bibliography (default is HTML).  Can be 
-#' text, bibtex, html, or other formats defined forthe print bibentry class, 
+#' @param style formatting style to print bibliography (default is plain text).  Can be 
+#' text, bibtex, html, textVersion, R, citation, or other formats defined forthe print bibentry class, 
 #' see ?print.bibentry for details.  
 #' @param sort logical indicating if bibliography should be sorted
 #' alphabetically, defaults to FALSE
-#' @param bibtex logical, use bibtex data structure internally? (internal option only) 
+#' @param bibtex logical, use bibtex data structure internally? (internal option only)
+#' @param .bibstyle the bibstyle function call or string. Defaults to journal of statistical software (JSS).  See \code{\link{bibstyle}}.
+#' @param ... additional arguments passed to print.bibentry, see \code{\link{bibentry}}
 #' @return a list of bibentries, providing a bibliography of what's been cited
-#' @details reads in the values from the option "works_cited",
-#' possibly applying tidying up and formatting as well.
+#' @details Formating of the return data is handled by bibentry printing methods.  
 #' @examples 
 #' bib <- c(citation("knitr"), citation("knitr"), citation("bibtex"), citation("bibtex"), citation("knitr"), citation("knitcitations"), citation("bibtex"))
 #' citep(bib)
 #' bibliography()
 #' 
 #' @export
-bibliography <- function(style="html", sort=FALSE, bibtex=getOption("bibtex_data")){
+bibliography <- function(style="textVersion", .bibstyle = "JSS", sort=FALSE, bibtex=getOption("bibtex_data"), ...){
   out <- read_cache(bibtex=bibtex)
   if(length(out)>0){
     if(sort){   
@@ -22,12 +23,34 @@ bibliography <- function(style="html", sort=FALSE, bibtex=getOption("bibtex_data
       out <- out[ordering]
     }
   }
-  invisible(output <- print(out, style))
+  if(style %in% c("html", "R", "text", "bibtex", "textVersion", "citation")){
+    output <- print(out, style, .bibstyle=.bibstyle, ...)
+    print(output)
+  } else if(style == "rdfa"){
+    output <- sapply(out, print_rdfa)
+    names(output) = ""
+    output <- cat(paste0(unlist(output), collapse=""))
+  } else if(style == "markdown"){
+    warning("markdown style not yet available, using plain text")
+    output <- print(out, "textVersion", .bibstyle=.bibstyle)
+    print(output)
+  } else {
+    stop("Style not recognized")
+  }
+  invisible(output)
 }
 
 
 
 
+
+
+
+
+
+
+
+
 ####### Methods below are depricated ###########
 
 #' A simple method to determine unique bibentries by bibkey
